@@ -1,7 +1,7 @@
 /*
  * tools/lib/lv_check_stripesize.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * May 1997
  * July,October 1999
@@ -39,9 +39,7 @@
 int lv_check_stripesize ( int stripesize) {
    int ret = -1;
 
-#ifdef DEBUG
    debug_enter ( "lv_check_check_stripesize -- CALLED\n");
-#endif
 
    if ( stripesize == 1) return 0;
 
@@ -51,8 +49,6 @@ int lv_check_stripesize ( int stripesize) {
         ( stripesize & ( stripesize - 1)) == 0 ) ret = 0;
    else ret =  -LVM_ELV_CHECK_STRIPE_SIZE;
 
-#ifdef DEBUG
    debug_leave ( "lv_check_check_stripesize -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
