@@ -1,9 +1,11 @@
 /*
  * tools/lib/lvm_check_chars.c
  *
- * Copyright (C) 1998  Heinz Mauelshagen, Germany
+ * Copyright (C) 1998  Heinz Mauelshagen, Sistina Software
  *
  * September 1998
+ * May 1999
+ * January 2000
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -23,31 +25,38 @@
  *
  */
 
+/*
+ * Changelog
+ *
+ *    17/05/1999 - added '.' as a valid character (lv_check_name and
+ *                 vg_check_name have been enhanced to)
+ *    31/01/2000 - use debug_enter()/debug_leave()
+ *
+ */
+
 #include <liblvm.h>
 
 int lvm_check_chars ( char *name) {
    int ret = 0;
 
-#ifdef DEBUG
-   debug ( "lvm_check_chars -- CALLED\n");
-#endif
+   debug_enter ( "lvm_check_chars -- CALLED with name: \"%s\"\n", name);
 
-   if ( name == NULL) return -LVM_EPARAM;
-
-   while ( *name != 0) {
-      if ( !isalnum ( *name) &&
-           *name != '_' &&
-           *name != '-' &&
-           *name != '+' &&
-           *name != '/') {
-         ret = -LVM_ELVM_CHECK_CHARS;
-         break;
+   if ( name == NULL) ret = -LVM_EPARAM;
+   else {
+      while ( *name != 0) {
+         if ( !isalnum ( *name) &&
+              *name != '.' &&
+              *name != '_' &&
+              *name != '-' &&
+              *name != '+' &&
+              *name != '/') {
+            ret = -LVM_ELVM_CHECK_CHARS;
+            break;
+         }
+         name++;
       }
-      name++;
    }
 
-#ifdef DEBUG
-   debug ( "lvm_check_chars -- LEAVING\n");
-#endif
+   debug_leave ( "lvm_check_chars -- LEAVING with ret: %d\n", ret);
    return ret;
 }
