@@ -7,6 +7,7 @@
  * February,April 1999
  * January,April 2000
  * February 2001
+ * January 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -38,6 +39,7 @@
  *    31/01/2000 - use debug_enter()/debug_leave()
  *    26/04/2000 - added DASD major support
  *    07/02/2001 - added COMPAQ_CISS major support
+ *    16/01/2002 - addedd ATARAID support
  *
  */
 
@@ -55,6 +57,9 @@ int lvm_check_dev ( struct stat *stat_b, int check_mode) {
 #endif
 #ifdef NBD_MAJOR
       NBD_MAJOR,
+#endif
+#ifdef ATARAID_MAJOR
+      ATARAID_MAJOR,
 #endif
       -1
    };
