@@ -1,9 +1,10 @@
 /*
  * tools/lib/lvm_error.c
  *
- * Copyright (C)  2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C)  2000 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * February,March,July,October 2000
+ * January 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -29,6 +30,7 @@
  *   17/03/2000 - changed namelist to uuidlist
  *   01/07/2000 - extended snaphsot related data
  *   30/10/2000 - use strerror() in I am not apple to supply one of my own
+ *   29/01/2003 - removed wrong PV size maximum error
  *
  */
 
@@ -167,7 +169,7 @@ char *lvm_error ( int error) {
       { LVM_ELV_WRITE_WRITE, "lv_write(): write"},
       { LVM_EPE_LOCK, "pe_lock(): lock"},
       { LVM_EPV_MOVE_LV_LE_REMAP, "pv_move(): LE of LV remap"},
-      { LVM_EPV_MOVE_PE_LLSEEK_IN, "pv_move_pe(): llsek input extent"},
+      { LVM_EPV_MOVE_PE_LLSEEK_IN, "pv_move_pe(): llseek input extent"},
       { LVM_EPV_MOVE_PE_LLSEEK_OUT, "pv_move_pe(): llseek output extent"},
       { LVM_EPV_MOVE_PE_LOCK, "pv_move_pe(): PE lock"},
       { LVM_EPV_MOVE_PE_LV_GET_NAME, "pv_move_pe(): lv_get_name"},
@@ -417,8 +419,6 @@ char *lvm_error ( int error) {
       { LVM_EVG_WRITE_LSEEK, "vg_write(): lseek"},
       { LVM_EVG_WRITE_OPEN, "vg_write(): open"},
       { LVM_EVG_WRITE_WRITE, "vg_write(): write"},
-      { LVM_EVG_SETUP_FOR_CREATE_PV_SIZE_MAX, "vg_setup_for_create(): PV"
-        "size too large"},
       { 0, NULL}
    };
 
