@@ -40,6 +40,9 @@
 
 #include <liblvm.h>
 
+static unsigned int _calc_pe_start_v1(pv_t *pv);
+static void _adjust_on_disk_size(pv_t *pv);
+
 pv_t *pv_copy_from_disk(pv_disk_t *pv_disk)
 {
 	pv_t *pv = NULL;
@@ -89,6 +92,16 @@ pv_t *pv_copy_from_disk(pv_disk_t *pv_disk)
 #undef xx16
 #undef xx32
 
+	/* handle version 1 structures */
+	if (pv->version == 1)
+		pv->pe_start = _calc_pe_start_v1(pv);
+
+	else if (pv->version == 2) {
+		/* let's down grade version 2 structures */
+		pv->version = 1;
+		_adjust_on_disk_size(pv);
+	}
+
  out:
 	debug_leave("pv_copy_from_disk -- LEAVING ret = %p\n", pv);
 	return pv;
@@ -141,10 +154,22 @@ pv_disk_t *pv_copy_to_disk(pv_t *pv_core)
 #undef xx16
 #undef xx32
 
+	/* this should be 0 for version 1 structures */
+	if (pv_core->version == 1)
+		pv->pe_start = 0;
+
  out:
 	debug_leave ( "pv_copy_to_disk -- LEAVING\n");
 	return pv;
 }
 
+static unsigned int _calc_pe_start_v1(pv_t *pv)
+{
+	return ((pv->pe_on_disk.base + pv->pe_on_disk.size) / SECTOR_SIZE);
+}
 
-
+static void _adjust_on_disk_size(pv_t *pv)
+{
+	pv->pe_on_disk.size = (pv->pe_start * SECTOR_SIZE) -
+		pv->pe_on_disk.base;
+}
