@@ -39,16 +39,11 @@ kdev_t pv_create_kdev_t ( char *dev_name) {
    int ret = 0;
    struct stat stat_b;
 
-#ifdef DEBUG
    debug_enter ( "pv_create_kdev_t -- CALLED with \"%s\"\n", dev_name);
-#endif
 
-   if ( dev_name == NULL || pv_check_name ( dev_name) < 0 ||
-        stat ( dev_name, &stat_b) == -1) ret = 0;
-   else                                  ret = stat_b.st_rdev;
+   if ( pv_check_name ( dev_name) == 0 && stat ( dev_name, &stat_b) == 0)
+      ret = stat_b.st_rdev;
 
-#ifdef DEBUG
    debug_leave ( "pv_create_kdev_t -- LEAVING with ret: %X\n", ret);
-#endif
    return ret;
 }
