@@ -1,11 +1,12 @@
 /*
  * tools/lib/pv_read_all_pe_of_vg.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
  *
  * March-May,October-November 1997
  * May,August,November 1998
  * January 2000
+ * April,November 2001
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -29,6 +30,8 @@
  * Changelog
  *
  *    03/02/2000 - use debug_enter()/debug_leave()
+ *    09/04/2001 - cleaned up debug output (Andreas Dilger)
+ *    22/11/2001 - avoided unnecessary pv_check_number() call
  *
  */
 
@@ -42,12 +45,9 @@ int pv_read_all_pe_of_vg ( char *vg_name, pe_disk_t ***pe, int reread) {
    static int first = 0;
    static char vg_name_sav[NAME_LEN] = { 0, };
    pv_t **pv_tmp = NULL;
-   pe_disk_t **pe_this = NULL;
-   static pe_disk_t **pe_this_sort = NULL;
+   static pe_disk_t **pe_this = NULL;
 
-#ifdef DEBUG
    debug_enter ( "pv_read_all_pe_of_vg -- CALLED\n");
-#endif
 
    if ( vg_name == NULL ||
         vg_check_name ( vg_name) < 0 ||
@@ -78,64 +78,35 @@ int pv_read_all_pe_of_vg ( char *vg_name, pe_disk_t ***pe, int reread) {
          goto pv_read_all_pe_of_vg_end;
       pv_count = 0;
       for ( p = 0; pv_tmp[p] != NULL; p++) pv_count++;
-#ifdef DEBUG
       debug ( "pv_read_all_pe_of_vg -- pv_count: %d\n", pv_count);
-#endif
       if ( ( pe_this = malloc ( ( pv_count+1) * sizeof ( pe_disk_t*))) == NULL){
          fprintf ( stderr, "malloc error in %s [line %d]\n",
                            __FILE__, __LINE__);
          ret = -LVM_EPV_READ_ALL_PE_OF_VG_MALLOC;
          goto pv_read_all_pe_of_vg_end;
       }
-      if ( ( pe_this_sort =
-             malloc ( ( pv_count+1) * sizeof ( pe_disk_t*))) == NULL) {
-         fprintf ( stderr, "malloc error in %s [line %d]\n",
-                           __FILE__, __LINE__);
-         ret = -LVM_EPV_READ_ALL_PE_OF_VG_MALLOC;
-         goto pv_read_all_pe_of_vg_end;
-      }
       for ( p = 0; pv_tmp[p] != NULL; p++) {
          if ( ( ret = pv_read_pe ( pv_tmp[p],
                                    &pe_this[p])) < 0) {
             goto pv_read_all_pe_of_vg_end;
          }
-#ifdef DEBUG
          debug ( "pv_read_all_pe_of_vg -- %s with %lu PE at address %X\n",
                   pv_tmp[p]->pv_name, pv_tmp[p]->pe_total, ( uint) &pe_this[p]);
-#endif
       }
       pe_this[p] = NULL;
 
-      if ( pv_check_number ( pv_tmp, p) < 0) {
-         ret = -LVM_EPV_READ_ALL_PE_OF_VG_PV_NUMBER;
-         goto pv_read_all_pe_of_vg_end;
-      }
+      debug ( "pv_read_all_pe_of_vg -- AFTER LOOP of pv_read_pe\n");
+      for ( p = 0; p < pv_count; p++)
+         debug ( "pv_read_all_pe_of_vg -- %s with %u PE at %X for PV #%d\n",
+                 pv_tmp[p]->pv_name, pv_tmp[p]->pe_total, (uint)pe_this[p], p);
 
-      for ( p = 0; pe_this[p] != NULL; p++)
-         pe_this_sort[pv_tmp[p]->pv_number-1] = pe_this[p];
-
-#ifdef DEBUG
-      if ( opt_d > 0) {
-         debug ( "pv_read_all_pe_of_vg -- AFTER LOOP of pv_read_pe\n");
-         for ( p = 0; pe_this[p] != NULL; p++)
-            debug ( "pv_read_all_pe_of_vg -- %s with %u PE at address %X "
-                    "for PV #%d\n",
-                    pv_tmp[p]->pv_name,
-                    pv_tmp[p]->pe_total,
-                    ( uint) pe_this[p],
-                    p);
-      }
-#endif
       first = 1;
    }
 
-   free ( pe_this);
-
-   *pe = pe_this_sort;
+   *pe = pe_this;
 
 pv_read_all_pe_of_vg_end:
-#ifdef DEBUG
+
    debug_leave ( "pv_read_all_pe_of_vg -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 } /* pv_read_all_pe_of_vg() */
