@@ -1,12 +1,13 @@
 /*
  * tools/lib/vg_check_consistency.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * March 1997
  * May,September 1998
  * January 1999
  * January 2000
+ * January 2001
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -32,6 +33,7 @@
  *    09/05/1998 - added vg_status checks
  *    15/01/1999 -           "
  *    08/02/2000 - use debug_enter()/debug_leave()
+ *    08/01/2001 - return correct error code
  *
  */
 
@@ -41,9 +43,7 @@ int vg_check_consistency ( vg_t *vg) {
    int ret = 0;
    ulong size = 0;
 
-#ifdef DEBUG
    debug_enter ( "vg_check_consistency -- CALLED\n");
-#endif
 
    if ( vg == NULL) ret = -LVM_EPARAM;
    else if ( vg_check_name ( vg->vg_name) < 0)
@@ -79,9 +79,7 @@ int vg_check_consistency ( vg_t *vg) {
          ret = -LVM_EVG_CHECK_CONSISTENCY_PVG_TOTAL;
    }
 
-#ifdef DEBUG
    debug_leave ( "vg_check_consistency -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
 
@@ -89,9 +87,7 @@ int vg_check_consistency ( vg_t *vg) {
 int vg_check_consistency_with_pv_and_lv ( vg_t *vg) {
    int ret = 0;
 
-#ifdef DEBUG
    debug_enter ( "vg_check_consistency_with_pv_and_lv -- CALLED\n");
-#endif
 
    ret = vg_check_consistency ( vg);
    if ( ret == 0) {
@@ -99,10 +95,7 @@ int vg_check_consistency_with_pv_and_lv ( vg_t *vg) {
       if ( ret == 0) ret = lv_check_consistency_all_lv ( vg);
    }
 
-#ifdef DEBUG
    debug_leave ( "vg_check_consistency_with_pv_and_lv -- LEAVING with "
                  "ret: %d\n", ret);
-#endif
-
-   return 0;
+   return ret;
 }
