@@ -44,9 +44,7 @@ int vg_create_dir_and_group_and_nodes ( vg_t *vg, int opt_v) {
    int ret = 0;
    int total_ret = 0;
 
-#ifdef DEBUG
    debug_enter ( "vg_create_dir_and_group_and_nodes -- CALLED\n");
-#endif
 
    if ( vg == NULL || vg_check_consistency_with_pv_and_lv < 0 ||
         opt_v < 0) {
@@ -61,8 +59,7 @@ int vg_create_dir_and_group_and_nodes ( vg_t *vg, int opt_v) {
    if ( ( ret = vg_create_dir_and_group ( vg)) < 0) {
       total_ret--;
       if ( ret == -LVM_EVG_CREATE_DIR_AND_GROUP_MKDIR) {
-         fprintf ( stderr, "%s -- problem creating volume group "
-                           "directory "
+         fprintf ( stderr, "%s -- problem creating volume group directory "
                            LVM_DIR_PREFIX
                            "%s\n",
                            cmd, vg->vg_name);
@@ -113,9 +110,8 @@ int vg_create_dir_and_group_and_nodes ( vg_t *vg, int opt_v) {
 
 vg_create_dir_and_group_and_nodes_end:
    if ( ret == 0) ret = total_ret;
-#ifdef DEBUG
+
    debug_leave ( "vg_create_dir_and_group_and_nodes -- LEAVING with ret: %d\n",
                   ret);
-#endif
    return ret;
 }
