@@ -1,12 +1,14 @@
 /*
  * tools/lib/vg_read_with_pv_and_lv.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March,October,November 1997
  * June,August 1998
  * January,March 1999
  * January 2000
+ * January,April 2001
+ * February 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -34,6 +36,8 @@
  *    20/03/1999 - added major device number correction in case
  *                 of old block device major 
  *    08/02/2000 - use debug_enter()/debug_leave()
+ *    08/01/2001 - set up core pointers for snapshots
+ *    07/02/2002 - check for NULL entries in pv array
  *
  */
 
@@ -54,9 +58,7 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
    vg_t *vg_this = NULL;
    pv_t **pv = NULL;
 
-#ifdef DEBUG
    debug_enter ( "vg_read_with_pv_and_lv -- CALLED\n");
-#endif
 
    if ( vg_name == NULL || vg == NULL ||
         vg_check_name ( vg_name) < 0) {
@@ -69,10 +71,8 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
         ret != -LVM_EVG_READ_VG_EXPORTED)
       goto vg_read_with_pv_and_lv_end;
 
-#ifdef DEBUG
    debug ( "vg_read_with_pv_and_lv -- AFTER vg_read; "
             " vg_this->lv_cur: %lu\n", vg_this->lv_cur);
-#endif
 
    if ( vg_this->pv_cur == 0) {
       ret = -LVM_EVG_READ_WITH_PV_AND_LV_PV_CUR;
@@ -81,33 +81,25 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
 
    if ( ( ret = pv_read_all_pv_of_vg ( vg_name, &pv, FALSE)) < 0)
       goto vg_read_with_pv_and_lv_end;
-
-#ifdef DEBUG
    debug ( "vg_read_with_pv_and_lv -- AFTER pv_read_all_pv_of_vg\n");
-#endif
-
    if ( ( ret = pv_read_all_pe_of_vg ( vg_name, &pe, FALSE)) < 0)
       goto vg_read_with_pv_and_lv_end;
-
-#ifdef DEBUG
    debug ( "vg_read_with_pv_and_lv -- AFTER pv_read_all_pe_of_vg\n");
-#endif
-
    if ( ( ret = lv_read_all_lv ( vg_name, &lv, FALSE)) < 0)
       goto vg_read_with_pv_and_lv_end;
 
-#ifdef DEBUG
    debug ( "vg_read_with_pv_and_lv -- AFTER lv_read_all_lv;"
             " vg_this->pv_cur: %lu  vg_this->pv_max: %lu  ret: %d\n",
             vg_this->pv_cur, vg_this->pv_max, ret);
-#endif
 
    if ( ret == 0) {
-#ifdef DEBUG
       debug (  "vg_read_with_pv_and_lv -- BEFORE for PE\n");
-#endif
       /* set up PE pointers in PVs */
       for ( p = 0; p < vg_this->pv_cur; p++) {
+         if ( pv[p] == NULL) {
+            ret = -LVM_EVG_READ_WITH_PV_AND_LV_PV_CUR;
+            goto vg_read_with_pv_and_lv_end;
+         }
          if ( ( vg_this->pv[p] = malloc ( sizeof ( pv_t))) == NULL) {
             fprintf ( stderr, "malloc error in %s [line %d]\n",
                               __FILE__, __LINE__);
@@ -126,14 +118,9 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
          }
          memcpy ( vg_this->pv[p]->pe, pe[p], size);
       }
-#ifdef DEBUG
       debug (  "vg_read_with_pv_and_lv -- AFTER for PE\n");
-#endif
-
       /* build the lv_current_pe structure array */
-#ifdef DEBUG
       debug (  "vg_read_with_pv_and_lv -- BEFORE for LV\n");
-#endif
       for ( l = 0; l < vg_this->lv_max; l++) vg_this->lv[l] = NULL;
       if ( vg_this->lv_cur > 0) {
          for ( l = 0; l < vg_this->lv_max; l++) {
@@ -147,11 +134,9 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
                   goto vg_read_with_pv_and_lv_end;
                }
                memcpy ( vg_this->lv[l], lv[l], sizeof ( lv_t));
-#ifdef DEBUG
                debug ( "vg_read_with_pv_and_lv -- vg_this->lv[%d]->"
                         "lv_allocated_le: %lu\n", l,
                         vg_this->lv[l]->lv_allocated_le);
-#endif
                if ( ( vg_this->lv[l]->lv_current_pe = malloc (
                          vg_this->lv[l]->lv_allocated_le *
                          sizeof ( pe_t))) == NULL) {
@@ -171,7 +156,7 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
                         vg_this->lv[l]->lv_current_pe[pe_index].dev =
                            vg_this->pv[p]->pv_dev;
                         vg_this->lv[l]->lv_current_pe[pe_index].pe =
-			   LVM_PE_DISK_OFFSET( ope, vg_this->pv[p]);
+				get_pe_offset(ope, vg_this->pv[p]);
                         vg_this->lv[l]->lv_current_pe[pe_index].reads = \
                         vg_this->lv[l]->lv_current_pe[pe_index].writes = 0;
                         npe++;
@@ -179,13 +164,17 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
                   }
                }
                if ( npe != vg_this->lv[l]->lv_allocated_le) {
+                  fprintf ( stderr,
+                            "%s -- only found %d of %d LEs for LV %s (%d)\n",
+                            cmd, npe, vg_this->lv[l]->lv_allocated_le,
+                            vg_this->lv[l]->lv_name, l);
                   ret = -LVM_EVG_READ_WITH_PV_AND_LV_LV_ALLOCATED_LE;
                   goto vg_read_with_pv_and_lv_end;
                }
                /* correct LVM_BLK_MAJOR */
                if ( MAJOR ( vg_this->lv[l]->lv_dev) != LVM_BLK_MAJOR) {
-                  vg_this->lv[l]->lv_dev = ( LVM_BLK_MAJOR << MINORBITS) +
-                                           MINOR ( vg_this->lv[l]->lv_dev);
+                  vg_this->lv[l]->lv_dev = MKDEV(LVM_BLK_MAJOR,
+						 MINOR(vg_this->lv[l]->lv_dev));
                }
             } else vg_this->lv[l] = NULL;
          }
@@ -193,10 +182,13 @@ int vg_read_with_pv_and_lv ( char *vg_name, vg_t **vg) {
    } /* if ( ret == 0) */
 
    if ( ret == 0) *vg = vg_this;
+   else goto vg_read_with_pv_and_lv_end;
+
+   /* Set up core pointers for snapshots */
+   vg_setup_pointers_for_snapshots ( *vg);
 
 vg_read_with_pv_and_lv_end:
-#ifdef DEBUG
+
    debug_leave ( "vg_read_with_pv_and_lv -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
