@@ -1,12 +1,12 @@
 /*
  * tools/lib/vg_show.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * March 1997
  * May,June 1998
  * November 1999
- * January 2000
+ * January,March 2000
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -33,17 +33,19 @@
  *    14/06/1998 - changed display order in vg_show_with_pv_and_lv()
  *    03/11/1999 - implemented vg_show_colon to generate colon seperated output
  *    08/02/2000 - use debug_enter()/debug_leave()
+ *    08/03/2000 - implemented cluster/shared display
+ *    28/03/2000 - added UUID display to pv_show_colon() and pv_show()
  *
  */
 
 #include <liblvm.h>
 
 void vg_show_colon ( vg_t *vg) {
-#ifdef DEBUG
+
    debug_enter ( "vg_show_colon -- CALLED\n");
-#endif
+
    if ( vg != NULL && vg_check_name ( vg->vg_name) == 0) {
-      printf ( "%s:%d:%d:%d:%d:%d:%d:%Ld:%d:%d:%d:%d:%d:%d:%d:%d\n",
+      printf ( "%s:%d:%d:%d:%d:%d:%d:%llu:%d:%d:%d:%Lu:%u:%d:%d:%d:%s\n",
                vg->vg_name,
                vg->vg_access,
                vg->vg_status,
@@ -51,21 +53,20 @@ void vg_show_colon ( vg_t *vg) {
                vg->lv_max,
                vg->lv_cur,
                vg->lv_open,
-               LVM_LV_SIZE_MAX(vg) / 2,
+               LVM_LV_SIZE_2TB(vg),
                vg->pv_max,
                vg->pv_cur,
                vg->pv_act,
-               vg->pe_total * vg->pe_size / 2,
+               ( unsigned long long) vg->pe_total * ( vg->pe_size / 2),
                vg->pe_size,
                vg->pe_total,
                vg->pe_allocated,
-               vg->pe_total - vg->pe_allocated
+               vg->pe_total - vg->pe_allocated,
+               strlen ( vg->vg_uuid) > 0 ? lvm_show_uuid ( vg->vg_uuid) : "none"
              );
    }
 
-#ifdef DEBUG
    debug_leave ( "vg_show_colon -- LEAVING\n");
-#endif
    return;
 }
 
@@ -73,16 +74,16 @@ void vg_show_colon ( vg_t *vg) {
 void vg_show ( vg_t *vg) {
    char *dummy = NULL;
 
-#ifdef DEBUG
    debug_enter ( "vg_show -- CALLED\n");
-#endif
 
    if ( vg != NULL || vg_check_name ( vg->vg_name) == 0) {
       printf ( "--- Volume group ---\n");
       printf ( "VG Name               %s\n", vg->vg_name);
       printf ( "VG Access             ");
       if ( vg->vg_access == ( VG_READ | VG_WRITE)) printf ( "read/write\n");
-      else                                         printf ( "read\n");
+      else if ( vg->vg_access == VG_READ)          printf ( "read\n");
+           else if ( vg->vg_access == VG_WRITE)    printf ( "write\n");
+	        else                               printf ( "error\n");
       printf ( "VG Status             ");
       if ( ! ( vg->vg_status & VG_ACTIVE)) printf ( "NOT ");
       printf ( "available");
@@ -91,11 +92,16 @@ void vg_show ( vg_t *vg) {
       if ( ! ( vg->vg_status & VG_EXTENDABLE)) printf ( "NOT ");
       printf ( "resizable\n");
       printf ( "VG #                  %u\n", vg->vg_number);
+      if ( vg->vg_access & VG_CLUSTERED) {
+         printf ( "Clustered             yes\n");
+         printf ( "Shared                %s\n",
+                  ( vg->vg_access & VG_SHARED) ? "yes" : "no");
+      }
       printf ( "MAX LV                %u\n", vg->lv_max);
       printf ( "Cur LV                %u\n", vg->lv_cur);
       printf ( "Open LV               %u\n", vg->lv_open);
       printf ( "MAX LV Size           %s\n",
-               ( dummy = lvm_show_size ( LVM_LV_SIZE_MAX(vg) / 2, SHORT)));
+               ( dummy = lvm_show_size ( LVM_LV_SIZE_2TB(vg) / 2, SHORT)));
       free ( dummy);
       printf ( "Max PV                %u\n", vg->pv_max);
       printf ( "Cur PV                %u\n", vg->pv_cur);
@@ -105,7 +111,9 @@ void vg_show ( vg_t *vg) {
       printf ( "VGDA                  %u\n", vg->vgda);
 #endif
       printf ( "VG Size               %s\n",
-               ( dummy = lvm_show_size ( vg->pe_total * vg->pe_size / 2, SHORT)));
+               ( dummy = lvm_show_size ( ( unsigned long long)
+                                         vg->pe_total * ( vg->pe_size / 2),
+                                         SHORT)));
       free ( dummy);
       printf ( "PE Size               %s\n",
                ( dummy = lvm_show_size ( vg->pe_size / 2, SHORT)));
@@ -113,30 +121,30 @@ void vg_show ( vg_t *vg) {
       printf ( "Total PE              %u\n", vg->pe_total);
       printf ( "Alloc PE / Size       %u / %s\n",
                vg->pe_allocated,
-               ( dummy = lvm_show_size ( vg->pe_allocated * vg->pe_size / 2,
+               ( dummy = lvm_show_size ( vg->pe_allocated * ( vg->pe_size / 2),
                                          SHORT)));
       free ( dummy);
       printf ( "Free  PE / Size       %u / %s\n",
                vg->pe_total - vg->pe_allocated,
-               ( dummy = lvm_show_size ( ( vg->pe_total - vg->pe_allocated) *
-                                      vg->pe_size / 2, SHORT)));
+               ( dummy = lvm_show_size ( ( unsigned long long)
+                                         ( vg->pe_total - vg->pe_allocated) *
+                                         ( vg->pe_size / 2), SHORT)));
       free ( dummy);
 #ifdef LVM_FUTURE
       printf ( "Total PVG             %u\n", vg->pvg_total);
 #endif
+      printf ( "VG UUID               %s\n",
+               strlen ( vg->vg_uuid) > 0 ? lvm_show_uuid ( vg->vg_uuid) : "none");
    }
 
-#ifdef DEBUG
    debug_leave ( "vg_show -- LEAVING\n");
-#endif
    return;
 }
 
 
 void vg_show_with_pv_and_lv ( vg_t *vg) {
-#ifdef DEBUG
+
    debug_enter ( "vg_show_with_pv_and_lv -- CALLED\n");
-#endif
 
    if ( vg != NULL || vg_check_name ( vg->vg_name) == 0) {
       vg_show ( vg);
@@ -146,8 +154,6 @@ void vg_show_with_pv_and_lv ( vg_t *vg) {
       pv_show_all_pv_of_vg ( vg);
    }
 
-#ifdef DEBUG
    debug_leave ( "vg_show_with_pv_and_lv -- LEAVING\n");
-#endif
    return;
 }
