@@ -1,12 +1,13 @@
 /*
  * tools/vgcfgrestore.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * June,October 1997
  * May 1998
  * October 1999
  * February 2000
+ * February 2002
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,6 +47,13 @@
  *    23/01/2001 - added call to lvm_init (JT)
  *    06/04/2001 - Tidy usage message and command-line options.
  *    09/04/2001 - Fix spelling of argument in error message
+ *    06/02/2002 - Fix -o bug [HM]
+ *    07/02/2002 - fixes for > 1TB support
+ *               - avoid creating group and nodes file; let vgscan do that
+ *    13/02/2002 - implemented option -b
+ *    17/02/2002 - avoid trying a restore to physical volumes smaller
+ *                 than the VGDA size
+ *               - use pv_get_size_ll() for library compatibility
  *
  */
 
@@ -57,6 +65,10 @@ char *cmd = NULL;
 int opt_d = 0;
 #endif
 
+int vg_backup_number = 0;
+char vg_backup_path[PATH_MAX];
+char *vg_conf_path = NULL;
+
 void usage ( int ret)
 {
    FILE *stream = stderr;
@@ -68,24 +80,62 @@ void usage ( int ret)
    }
 
    fprintf ( stream, "%s "
+             "[-b|--backup_number BackupNumber] "
              DEBUG_HELP_2
-             "[-f|--file VGConfPath] "
-             "[-l[l]|--list [--list]]\n\t"
-             "[-n|--name VolumeGroupName] "
-             "[-h|--help]\n\t"
+             "\n\t[-f|--file VGConfPath] "
+             "[-i|--ignoresize]\n\t"
+             "[-l[l]|--list [--list]]"
+             "[-n|--name VolumeGroupName]\n\t"
+             "[-h|--help]"
              "[-o|--oldpath OldPhysicalVolumePath] "
-             "[-t|--test] "
-             "[-v|--verbose]\n\t"
+             "[-t|--test]\n\t"
+             "[-v|--verbose]"
              "[--version] "
              "[PhysicalVolumePath]\n",
              cmd);
    exit ( ret);
 }
 
+inline void _setup_vg_backup_path ( int opt_b, int opt_f, char *vg_name) {
+   if ( opt_f == 0) {
+      memset ( vg_backup_path, 0, sizeof ( vg_backup_path));
+      if ( opt_b == 0) {
+         snprintf ( vg_backup_path, sizeof ( vg_backup_path) - 1,
+                                    "%s/%s.conf", VG_BACKUP_DIR, vg_name);
+      } else {
+         snprintf ( vg_backup_path, sizeof ( vg_backup_path) - 1,
+                                    "%s/%s.conf.%d.old",
+                                    VG_BACKUP_DIR, vg_name, vg_backup_number);
+      }
+      printf ( "%s -- INFO: using backup file \"%s\"\n", cmd, vg_backup_path);
+   } else {
+      int sz = 0;
+      if ( strchr ( vg_conf_path, '/') == NULL)
+         sz = sprintf ( vg_backup_path, "./");
+      snprintf ( &vg_backup_path[sz], sizeof ( vg_backup_path) - sz - 1,
+                                      "%s", vg_conf_path);
+   }
+}
+
+inline char *_from_vg_backup_path ( char *path) {
+   int i = 0;
+   static char vg_name[NAME_LEN];
+   char *p = strrchr ( path, '/');
+
+   if ( p == NULL) return NULL;
+   memset ( vg_name, 0, sizeof ( vg_name));
+   for ( p++; *p != '\0' && *p != '.'; p++) vg_name[i++] = *p;
+   return vg_name;
+}
+
+
 int main ( int argc, char **argv)
 {
    int c = 0;
+   int p = 0;
+   int opt_b = 0;
    int opt_f = 0;
+   int opt_i = 0;
    int opt_l = 0;
    int opt_n = 0;
    int opt_o = 0;
@@ -95,37 +145,42 @@ int main ( int argc, char **argv)
    int pv_index = -1;
    int pv_index_old = -1;
    int ret = 0;
-   char *options = "f:h?ln:o:tv" DEBUG_SHORT_OPTION;
+   long long pv_size;
+   char *options = "b:f:h?iln:o:tv" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
+      { "backup_number", required_argument, NULL, 'b'},
       DEBUG_LONG_OPTION
-      { "file",       required_argument, NULL, 'f'},
-      { "help",       no_argument,       NULL, 'h'},
-      { "list",       no_argument,       NULL, 'l'},
-      { "name",       required_argument, NULL, 'n'},
-      { "oldpath",    required_argument, NULL, 'o'},
-      { "test",       no_argument,       NULL, 't'},
-      { "verbose",    no_argument,       NULL, 'v'},
-      { "version",    no_argument,       NULL, 22},
+      { "file",          required_argument, NULL, 'f'},
+      { "help",          no_argument,       NULL, 'h'},
+      { "ignoresize",    no_argument,       NULL, 'i'},
+      { "list",          no_argument,       NULL, 'l'},
+      { "name",          required_argument, NULL, 'n'},
+      { "oldpath",       required_argument, NULL, 'o'},
+      { "rename",        required_argument, NULL, 'r'},
+      { "test",          no_argument,       NULL, 't'},
+      { "verbose",       no_argument,       NULL, 'v'},
+      { "version",       no_argument,       NULL, 22},
       { NULL, 0, NULL, 0}
    };
    char *pv_name = NULL;
    char *pv_name_old = NULL;
    char *vg_name = NULL;
-   char *vg_conf_path = NULL;
-   char vg_backup_path[NAME_LEN] = { 0, };
    pv_t *pv = NULL;
    vg_t vg;
-   vg_t vg_write;
 
    /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
    memset ( &vg, 0, sizeof ( vg));
-   memset ( &vg_write, 0, sizeof ( vg_write));
 
    while ( ( c = getopt_long ( argc, argv, options,
                                long_options, NULL)) != EOF) {
       switch ( c) {
+         case 'b':
+            vg_backup_number = lvm_check_number ( optarg, FALSE);
+            opt_b++;
+            break;
+
          DEBUG_HANDLE_CASE_D;
 
          case 'f':
@@ -136,6 +191,10 @@ int main ( int argc, char **argv)
          case 'h':
             usage(0);
 
+         case 'i':
+            opt_i++;
+            break;
+
          case 'l':
             opt_l++;
             break;
@@ -188,10 +247,17 @@ int main ( int argc, char **argv)
       usage(LVM_EINVALID_CMD_LINE);
    }
 
-   if ( opt_f > 0 && opt_n == 0) {
-      fprintf ( stderr, "%s -- please give option n with option f\n", cmd);
+   if ( opt_f == 0 && opt_n == 0) {
+      fprintf ( stderr, "%s -- please give either option f or n or both\n",
+                        cmd);
       usage ( LVM_EINVALID_CMD_LINE);
    }
+   if ( opt_f != 0 && opt_b != 0) {
+      fprintf ( stderr, "%s -- option b is not possible with option f\n", cmd);
+      usage ( LVM_EINVALID_CMD_LINE);
+   }
+
+   _setup_vg_backup_path ( opt_b, opt_f, vg_name);
 
    if ( opt_l == 0) {
       if ( optind != argc - 1) {
@@ -211,6 +277,7 @@ int main ( int argc, char **argv)
       }
    }
 
+   if ( opt_n == 0) vg_name = _from_vg_backup_path ( vg_backup_path);
    if ( opt_t == 0 && opt_l == 0 && vg_check_active ( vg_name) == TRUE) {
       fprintf ( stderr,
                 "%s -- can't restore part of active volume group \"%s\"\n",
@@ -218,10 +285,6 @@ int main ( int argc, char **argv)
       usage ( LVM_EVGCFGRESTORE_VG_CHECK_ACTIVE);
    }
 
-   if ( opt_f == 0)
-      sprintf ( vg_backup_path, "%s/%s.conf", VG_BACKUP_DIR, vg_name);
-   else strcpy ( vg_backup_path, vg_conf_path);
-
 
    LVM_CHECK_IOP;
    LVM_LOCK ( 0);
@@ -246,9 +309,23 @@ int main ( int argc, char **argv)
       vg_name = vg.vg_name;
       printf ( "%s -- this is a backup of volume group \"%s\"\n", cmd, vg_name);
    } else if ( strcmp ( vg_name, vg.vg_name) != 0) {
-      fprintf ( stderr, "%s -- this is not a backup of volume group \"%s\"\n\n",
-                cmd, vg_name);
-      return LVM_EVGCFGRESTORE_INVALID;
+      /* user wants to change volume group name during restore ->
+         change it in VG struct, all PV structs and in all LV structs */
+      int l;
+      printf ( "%s -- renaming volume group \"%s\" in backup to "
+               " volume group \"%s\"\n\n",
+               cmd, vg.vg_name, vg_name);
+      memset  ( vg.vg_name, 0, sizeof ( vg.vg_name));
+      strncpy ( vg.vg_name, vg_name, sizeof ( vg.vg_name) - 1);
+      for ( p = 0; p < vg.pv_cur; p++) {
+         if ( vg.pv[p] == NULL) continue;
+         memset  ( vg.pv[p]->vg_name, 0, sizeof ( vg.pv[p]->vg_name));
+         strncpy ( vg.pv[p]->vg_name, vg_name, sizeof ( vg.pv[p]->vg_name) - 1);
+      }
+      for ( l = 0; l < vg.lv_max; l++) {
+         if ( vg.lv[l] == NULL) continue;
+         strcpy ( vg.lv[l]->lv_name, lv_change_vgname ( vg_name, vg.lv[l]->lv_name));
+      }
    }
 
    if ( opt_v > 0) printf ( "%s -- checking volume group consistency"
@@ -318,22 +395,44 @@ int main ( int argc, char **argv)
          if ( pv_index_old > -1) index = pv_index_old;
          else                    index = pv_index;
 
-         if ( pv_get_size ( pv_name, NULL) !=  vg.pv[index]->pv_size) {
-            fprintf ( stderr,
-                      "%s -- size of physical volume %s differs from backup\n",
-                      cmd, pv_name);
-            return LVM_EVGCFGRESTORE_PV_GET_SIZE;
+         pv_size = pv_get_size_ll ( pv_name, NULL);
+         if ( opt_i == 0) {
+            if ( pv_size < 0LL || ( uint) pv_size != vg.pv[index]->pv_size) {
+               fprintf ( stderr,
+                         "%s -- size of physical volume %s differs "
+                         "from backup\n\n",
+                         cmd, pv_name);
+               return LVM_EVGCFGRESTORE_PV_GET_SIZE;
+            }
+         } else {
+            printf ( "%s -- forcing write of VGDA of \"%s\" to physical "
+                     "volume \"%s\"\n%s -- ignoring size mismatches\n",
+                     cmd, vg_name, pv_name, cmd);
+            if ( pv_size < LVM_VGDA_SIZE(vg.pv[index]) / SECTOR_SIZE) {
+               fprintf ( stderr,
+                         "%s -- size of physical volume %s is too small "
+                         "to store VGDA\n\n",
+                         cmd, pv_name);
+               return LVM_EVGCFGRESTORE_PV_GET_SIZE;
+            }
          }
 
-         memcpy ( &vg_write, &vg, sizeof ( vg));
-         vg_write.pv[0] = vg.pv[index];
-         vg_write.pv[1] = NULL;
+         vg.vg_number = lvm_tab_get_free_vg_number();
+         for ( p = 0; p < vg.pv_cur; p++) {
+            /* zero all pv_names for vg_write_with_pv_and_lv() which is
+               necessary for all PV UUIDs to be written */
+            memset ( vg.pv[p]->pv_name, 0, sizeof (vg.pv[p]->pv_name));
+         }
+         /* insert the new PV name so that vg_write_with_pv_and_lv()
+            does write the complete VGDA to that one */
+         strncpy( vg.pv[index]->pv_name, pv_name,
+                  sizeof(vg.pv[index]->pv_name) - 1);
 
          /* store VGDA from backup on physical volume */
          if ( opt_v)
             printf ( "%s -- writing VGDA of \"%s\" to physical volume \"%s\"\n",
-                     cmd, vg_name, vg_write.pv[0]->pv_name);
-         if ( ( ret = vg_write_with_pv_and_lv ( &vg_write)) < 0) {
+                     cmd, vg_name, vg.pv[index]->pv_name);
+         if ( ( ret = vg_write_with_pv_and_lv ( &vg)) < 0) {
             fprintf ( stderr,
                       "%s -- ERROR \"%s\" storing VGDA of \"%s\" on disks\n\n",
                       cmd, lvm_error ( ret), vg_name);
@@ -345,31 +444,6 @@ int main ( int argc, char **argv)
                      cmd, vg_name);
          vg_remove_dir_and_group_and_nodes ( vg_name);
    
-         if ( ( ret = vg_create_dir_and_group_and_nodes ( &vg, opt_v)) < 0) {
-            fprintf ( stderr, "%s -- %d errors creating volume group "
-                              "directory and special files\n\n",
-                              cmd, -ret);
-            return LVM_EVGCFGRESTORE_VG_REMOVE_DIR;
-         }
-   
-         if ( opt_v > 0) printf ( "%s -- inserting volume group \"%s\" "
-                                  "into \"%s\"\n",
-                                  cmd, vg_name, LVMTAB);
-         if ( ( ret = lvm_tab_vg_insert ( vg_name)) < 0 &&
-              ret != -LVM_ELVM_TAB_VG_INSERT_VG_EXISTS) {
-            fprintf ( stderr, "%s -- ERROR \"%s\" inserting volume group into "
-                              "\"%s\"\n\n",
-                              cmd, lvm_error ( ret), LVMTAB);
-            return LVM_EVGCFGRESTORE_LVM_TAB_VG_INSERT;
-         }
-         
-         if ( ( ret = vg_cfgbackup ( vg_name, LVMTAB_DIR,
-                                     opt_v, &vg)) < 0) {
-            fprintf ( stderr, "%s -- ERROR \"%s\" writing lvmtab\n\n",
-                              cmd, lvm_error ( ret));
-            return LVM_EVGCFGRESTORE_VG_CFGBACKUP;
-         }
-
          printf ( "%s -- VGDA for \"%s\" successfully restored "
                   "to physical volume \"%s\"\n",
                   cmd, vg_name, pv_name);
