@@ -1,13 +1,15 @@
 /*
  * tools/vgcreate.c
  *
- * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March-June 1997
  * May,June,September 1998
  * January,February,October 1999
  * February 2000
  * January,June 2001
+ * January 2002
+ * February 2002
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,8 +53,13 @@
  *                 with lvm_check_number() I forgot last time
  *    19/03/2001 - Improved the phrasing of error message
  *    09/04/2001 - Tidy usage message and command-line options.
- *    22/06/2001 - added Andreas Dilger's PE on 4k boundary alignment enhancements
+ *    22/06/2001 - added Andreas Dilger's PE on 4k boundary alignment
+ *                 enhancements
  *    27/06/2001 - fixed minimum PV size message
+ *    29/01/2002 - removed wrong PV size maximum message
+ *    06/02/2002 - cope with changed pv_get_size() return cast
+ *    07/02/2002 - fixes for > 1TB support
+ *    17/02/2002 - avoid calling pv_get_size()
  *
  */
 
@@ -101,14 +108,14 @@ int main ( int argc, char **argv) {
    int opt_v = 0;
    int p = 0;
    int p1 = 0;
-   int max_lv = MAX_LV - 1;
-   int max_pv = MAX_PV - 1;
+   int max_lv = MAX_LV;
+   int max_pv = MAX_PV;
    int min_pv_index = 0;
-   ulong max_pv_size = 0;
+   long long max_pv_size = 0;
    ulong min_pv_size = -1;
    long pe_size = LVM_DEFAULT_PE_SIZE;
    int ret = 0;
-   int size = 0;
+   uint size = 0;
    int v = 0;
    int vg_count = 0;
    char *dummy = NULL;
@@ -181,18 +188,17 @@ int main ( int argc, char **argv) {
                pe_size = ( (unsigned long long) pe_size * 1024) / SECTOR_SIZE;
                opt_s++;
                if (vg_check_pe_size(pe_size) < 0) {
-		       fprintf(stderr,
-			       "%s -- invalid physical extent size %s\n"
-			       "%s -- must be power of 2 and between "
-			       "%s and %s\n\n",
-			       cmd,
-			       lvm_show_size (sectors_to_k(pe_size), SHORT),
-			       cmd,
-			       lvm_show_size (sectors_to_k(LVM_MIN_PE_SIZE),
-			                      SHORT),
-			       lvm_show_size (sectors_to_k(LVM_MAX_PE_SIZE),
-			                     SHORT));
-		       usage(LVM_EINVALID_CMD_LINE);
+                  char *d1, *d2, *d3;
+		  d1 = lvm_show_size (sectors_to_k(pe_size), SHORT);
+		  d2 = lvm_show_size (sectors_to_k(LVM_MIN_PE_SIZE), SHORT);
+                  d3 = lvm_show_size (sectors_to_k(LVM_MAX_PE_SIZE), SHORT);
+		  fprintf(stderr,
+		          "%s -- invalid physical extent size %s\n"
+			  "%s -- must be power of 2 and between "
+			  "%s and %s\n\n",
+			  cmd, d1, cmd, d2, d3);
+                  free ( d1); free ( d2); free ( d3);
+		  usage(LVM_EINVALID_CMD_LINE);
                }
             } else {
                fprintf ( stderr, "%s -- ERROR option s argument \"%s\"\n",
@@ -307,22 +313,13 @@ int main ( int argc, char **argv) {
       for ( p = 0; pv[p] != NULL; p++) {
          if ( strcmp ( pv_name, pv[p]->pv_name) == 0) {
             if ( opt_v > 0) printf ( "%s -- checking physical volume \"%s\"\n"
-                                     "%s -- getting "
-                                     "size of physical volume \"%s\"\n",
+                                     "%s -- size of physical volume \"%s\" "
+                                     " is %u sectors\n"
+                                     "%s -- checking for new physical "
+                                     "volume \"%s\"\n",
                                      cmd, pv_name,
+                                     cmd, pv_name, pv[p]->pv_size,
                                      cmd, pv_name);
-	    if ( ( size = pv_get_size ( pv[p]->pv_name, NULL)) <= 0) {
-	       fprintf ( stderr, "%s -- ERROR \"%s\" getting size of "
-                                 "physical volume \"%s\"\n\n",
-                                 cmd, lvm_error ( size), pv_name);
-               return LVM_EVGCREATE_PV_GET_SIZE;
-            }
-            if ( opt_v > 0) printf ( "%s -- size of physical volume \"%s\" "
-                                     " is %d sectors\n",
-                                     cmd, pv_name, size);
-
-            if ( opt_v > 0) printf ( "%s -- checking for new physical "
-                                     "volume \"%s\"\n", cmd, pv_name);
             if ( pv_check_new ( pv[p]) == FALSE) {
                fprintf ( stderr, "%s -- \"%s\" is not a new physical volume\n",
 				 cmd, pv_name);
@@ -397,7 +394,7 @@ int main ( int argc, char **argv) {
 
    if ( opt_v > 0) printf ( "%s -- INFO: maximum of %d physical volumes\n",
                             cmd, max_pv);
-   if ( max_pv < 0 || max_pv <= np || max_pv > ABS_MAX_PV) {
+   if ( max_pv < 0 || max_pv < np || max_pv > ABS_MAX_PV) {
       fprintf ( stderr, "%s -- invalid maximum physical volumes -p %d\n\n",
                         cmd, max_pv);
       return LVM_EINVALID_CMD_LINE;
@@ -416,10 +413,10 @@ int main ( int argc, char **argv) {
             max_pv * NAME_LEN +
             max_lv * sizeof ( lv_t));
    if ( size / SECTOR_SIZE > min_pv_size / 5) {
-      fprintf ( stderr, "%s -- more than 20%% [%d KB] of physical volume "
+      fprintf ( stderr, "%s -- more than 20%% [%u KB] of physical volume "
                         "%s with %u KB would be used\n\n",
                         cmd,
-                        size,
+                        size / 2,
                         pvp[min_pv_index]->pv_name,
                         pvp[min_pv_index]->pv_size / 2);
       return LVM_EVGCREATE_PV_TOO_SMALL;
@@ -440,16 +437,6 @@ int main ( int argc, char **argv) {
 			     LVM_PE_SIZE_PV_SIZE_REL,
                              SHORT)));
                            free ( dummy); dummy = NULL;
-      } else if (ret == -LVM_EVG_SETUP_FOR_CREATE_PV_SIZE_MAX) {
-     	fprintf ( stderr, "%s -- ERROR: %d physical volume%s too large "
-			  "for physical extent size of %s\n"
-			  "%s -- maximum physical volume "
-			  "at this physical extent size is %s\n\n",
-			  cmd, count_sav, count_sav > 1 ? "s" : "",
-			  vg_name, cmd,
-			  ( dummy = lvm_show_size ( sectors_to_k(vg.pe_size) *
-			                            LVM_PE_T_MAX, SHORT)));
-			  free ( dummy); dummy = NULL;
       } else {
          fprintf ( stderr, "%s -- ERROR \"%s\" setting volume group \"%s\" up "
                            "for create\n\n",
@@ -464,7 +451,7 @@ int main ( int argc, char **argv) {
       free ( dummy); dummy = NULL;
    }
    printf ( "%s -- INFO: maximum logical volume size is %s\n",
-            cmd, ( dummy = lvm_show_size ( LVM_LV_SIZE_MAX ( &vg) / 2, LONG)));
+            cmd, ( dummy = lvm_show_size ( LVM_LV_SIZE_2TB ( &vg) / 2, LONG)));
    free ( dummy); dummy = NULL;
 
    lvm_dont_interrupt ( 0);
