@@ -1,12 +1,13 @@
 /*
  * tools/vgexport.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * May 1997
  * May,June,September 1998
  * October 1999
  * February 2000
+ * February 2002
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +42,10 @@
  *                 better performance
  *    06/10/1999 - implemented support for long options
  *    15/02/2000 - use lvm_error()
+ *    23/01/2001 - added call to lvm_init (JT)
+ *    09/04/2001 - Tidy usage message and command-line options.
+ *    07/02/2002 - avoid using lvm_tab_* functions so that we still can
+ *                 export in case we don't have cache files
  *
  */
 
@@ -52,6 +57,27 @@ char *cmd = NULL;
 int opt_d = 0;
 #endif
 
+void usage ( int ret)
+{
+   FILE *stream = stderr;
+
+   if ( ret == 0) {
+      stream = stdout;
+      printf ( "%s (IOP %d)\n\n", lvm_version, LVM_LIB_IOP_VERSION);
+      printf ( "%s -- unregister volume group from system\n", cmd);
+   }
+
+   fprintf ( stream, "\n%s "
+             "[-a|--all] "
+             DEBUG_HELP_2
+             "[-h|--help]\n\t"
+             "[-v|--verbose] "
+             "[--version] "
+             "VolumeGroupName [VolumeGroupName...]\n",
+             cmd);
+   exit ( ret);
+}
+
 int main ( int argc, char **argv) {
    int c = 0;
    int opt_a = 0;
@@ -59,26 +85,21 @@ int main ( int argc, char **argv) {
    int p = 0;
    int ret = 0;
    char *vg_name = NULL;
-#ifdef DEBUG
-   char *options = "adh?v";
-#else
-   char *options = "ah?v";
-#endif
+   char *options = "ah?v" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
       { "all",     no_argument, NULL, 'a'},
-#ifdef DEBUG
-      { "debug",   no_argument, NULL, 'd'},
-#endif
+      DEBUG_LONG_OPTION
       { "help",    no_argument, NULL, 'h'},
       { "verbose", no_argument, NULL, 'v'},
+      { "version", no_argument, NULL, 22 },
       { NULL,      0,           NULL, 0},
    };
    char vg_name_exp[NAME_LEN] = { 0, };
    vg_t *vg = NULL;
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
    LVMTAB_CHECK;
 
    while ( ( c = getopt_long ( argc, argv, options,
@@ -86,71 +107,52 @@ int main ( int argc, char **argv) {
       switch ( c) {
 
          case 'a':
-            if ( opt_a > 0) {
-               fprintf ( stderr, "%s -- a option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
             opt_a++;
             break;
 
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
 
          case 'h':
-         case '?':
-            printf ( "\n%s  (IOP %d)\n\n%s -- Volume Group Export\n\n"
-                     "Synopsis:\n"
-                     "---------\n\n"
-                     "%s\n"
-                     "\t[-a/--all]\n"
-#ifdef DEBUG
-                     "\t[-d/--debug]\n"
-#endif
-                     "\t[-h/-?/--help]\n"
-                     "\t[-v/--verbose]\n"
-                     "\tVolumeGroupName [VolumeGroupName...]\n\n",
-                     lvm_version, LVM_LIB_IOP_VERSION,  cmd, cmd);
-            return 0;
-            break;
+            usage ( 0);
 
          case 'v':
-            if ( opt_v > 0) {
-               fprintf ( stderr, "%s -- v option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
             opt_v++;
             break;
 
+         case 22:
+            printf ("%s: %s (IOP %d)\n", cmd, lvm_version, LVM_LIB_IOP_VERSION);
+            return 0;
+
          default:
             fprintf ( stderr, "%s -- invalid command line option \"%c\"\n\n",
                       cmd, c);
-            return LVM_EINVALID_CMD_LINE;
+         case '?':
+            usage ( LVM_EINVALID_CMD_LINE);
       }
    }
-  
+
+   /* not until all commands are converted
    CMD_MINUS_CHK;
+   */
+   if ( optind < argc && *argv[optind] == '-') {
+      fprintf ( stderr, "%s -- invalid option %s\n", cmd, argv[optind]);
+      usage ( LVM_EINVALID_CMD_LINE);
+   }
    LVM_CHECK_IOP;
    LVM_LOCK ( 0);
 
    if ( opt_a > 0) {
-      argv = lvm_tab_vg_check_exist_all_vg ();
+      argv = vg_check_exist_all_vg ();
       argc = optind = 0;
       if ( argv != NULL) while ( argv[argc] != NULL) argc++;
    
       if ( optind == argc) {
          printf ( "%s -- no volume groups found\n\n", cmd);
-         return LVM_EVGEXPORT_NO_VG;
+         usage ( LVM_EVGEXPORT_NO_VG);
       }
    } else if ( optind == argc) {
       fprintf ( stderr, "%s -- please give a volume group name\n\n", cmd);
-      return LVM_EVGEXPORT_VG_MISSING;
+      usage ( LVM_EVGEXPORT_VG_MISSING);
    }
 
 
@@ -171,14 +173,9 @@ int main ( int argc, char **argv) {
          continue;
       }
 
-      if ( opt_v > 0) printf ( "%s -- checking volume group existence\n", cmd);
-      if ( ( ret = lvm_tab_vg_check_exist ( vg_name, NULL)) != TRUE) {
-         fprintf ( stderr, "%s -- volume group \"%s\" doesn't exist\n",
-                   cmd, vg_name);
-         continue;
-      }
-
-      sprintf ( vg_name_exp, "%s%s%c", vg_name, EXPORTED, 0);
+      memset ( vg_name_exp, 0, sizeof ( vg_name_exp));
+      snprintf ( vg_name_exp, sizeof ( vg_name_exp) - 1,
+                              "%s%s", vg_name, EXPORTED);
       if ( ( ret = vg_check_exist ( vg_name_exp)) != TRUE) {
          if ( ret == -LVM_EVG_READ_VG_EXPORTED) {
             fprintf ( stderr, "%s -- a volume group named \"%s\" is "
@@ -190,7 +187,7 @@ int main ( int argc, char **argv) {
 
       if ( opt_v > 0) printf ( "%s -- reading data of volume group \"%s\" "
                                "from disk(s)\n", cmd, vg_name);
-      if ( ( ret = lvm_tab_vg_read_with_pv_and_lv ( vg_name, &vg)) != 0) {
+      if ( ( ret = vg_read_with_pv_and_lv ( vg_name, &vg)) != 0) {
          fprintf ( stderr, "%s -- ERROR \"%s\" reading data of volume "
                            "group \"%s\"\n\n",
                            cmd, lvm_error ( ret), vg_name);
@@ -251,14 +248,12 @@ int main ( int argc, char **argv) {
          fprintf ( stderr, "%s -- ERROR \"%s\" removing volume group \"%s\" "
                            "from \"%s\"\n",
                            cmd, lvm_error ( ret), vg_name, LVMTAB);
-         continue;
       }
 
       lvm_interrupt ();
 
       printf ( "%s -- volume group \"%s\"%s sucessfully exported\n",
                cmd, vg_name, ret < 0 ? " NOT" : "");
-      if ( ret < 0) continue;
 
    }
 
