@@ -179,6 +179,7 @@ int main ( int argc, char **argv) {
 
       if ( opt_v > 0)
          printf ( "%s -- checking for duplicate physical volumes\n", cmd);
+
       for ( p1 = 0; pv_this != NULL && pv_this[p1] != NULL; p1++) {
          if ( strcmp ( pv_name, pv_this[p1]->pv_name) == 0) {
             fprintf ( stderr, "%s -- duplicate physical volume \"%s\" \n\n",
@@ -217,6 +218,15 @@ int main ( int argc, char **argv) {
          usage ( LVM_EVGIMPORT_CHECK_EXPORTED);
       }
 
+      if ( opt_v > 0) printf ( "%s -- checking consistency of physical "
+                               "volume \"%s\"\n", cmd, pv_name);
+      if ( ( ret = pv_check_consistency ( pv)) < 0) {
+         fprintf ( stderr, "%s -- ERROR \"%s\" checking physical "
+                           "volume consistency of \"%s\"\n",
+                           cmd, lvm_error ( ret), pv_name);
+         continue;
+      }
+
       if ( opt_v > 0) printf ( "%s -- reallocating memory\n", cmd);
       if ( ( pv_this = realloc ( pv_this,
                                  ( p + 2) * sizeof ( pv_t*))) == NULL) {
@@ -232,15 +242,6 @@ int main ( int argc, char **argv) {
       }
       memcpy ( pv_this[p], pv, sizeof ( pv_t));
 
-      if ( opt_v > 0) printf ( "%s -- checking consistency of physical "
-                               "volume \"%s\"\n", cmd, pv_name);
-      if ( ( ret = pv_check_consistency ( pv_this[p])) < 0) {
-         fprintf ( stderr, "%s -- ERROR \"%s\" checking physical "
-                           "volume consistency of \"%s\"\n",
-                           cmd, lvm_error ( ret), pv_name);
-         continue;
-      }
-
       p++;
       pv_this[p] = NULL;
    }
@@ -267,13 +268,6 @@ int main ( int argc, char **argv) {
       if ( pv_number < pv_this[p]->pv_number) pv_number = pv_this[p]->pv_number;
    }
 
-   if ( pv_number != pv_number_this) {
-      fprintf ( stderr, "%s -- ERROR: wrong number of physical volumes "
-                        "to import volume group \"%s\"\n\n",
-                        cmd, vg_name);
-      return LVM_EVGIMPORT_PV_COUNT;
-   }
-
    /* get the physical volume numbers counter array */
    if ( ( pv_number_count = malloc ( pv_number * sizeof ( int))) == NULL) {
       fprintf ( stderr, "%s -- malloc error in file \"%s\" [line %d]\n\n",
@@ -287,6 +281,9 @@ int main ( int argc, char **argv) {
       pv_number_count[pv_this[p]->pv_number-1]++;
 
    for ( p = 0; p < pv_number; p++) {
+      if ( pv_number_count[p] == 0)
+         continue;
+
       if ( pv_number_count[p] != 1) {
          fprintf ( stderr, "%s -- ERROR: physical volume number %u "
                            "of \"%s\" occurs %d times\n\n",
@@ -319,7 +316,7 @@ int main ( int argc, char **argv) {
       return LVM_EVGIMPORT_PV_COUNT;
    }
 
-   /* continue checking consistency in red exported volume group */
+   /* continue checking consistency in read exported volume group */
    if ( opt_v > 0) printf ( "%s -- checking for correct system ids on "
                             "physical volumes of volume group \"%s\"\n",
                             cmd, vg->vg_name);
