@@ -36,6 +36,7 @@
  *    05/09/1998 - corrected some messages
  *    06/10/1999 - implemented support for long options
  *    15/02/2000 - use lvm_error()
+ *    23/01/2001 - added call to lvm_init (JT)
  *
  */
 
@@ -61,26 +62,20 @@ int main ( int argc, char **argv) {
    char **pv_names = NULL;
    char *vg_name = NULL;
    vg_t *vg = NULL;
-#ifdef DEBUG
-   char *options = "aA:dh?v";
-#else
-   char *options = "aA:h?v";
-#endif
+   char *options = "aA:h?v" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
       { "all",        no_argument,       NULL, 'a'},
       { "autobackup", required_argument, NULL, 'A'},
-#ifdef DEBUG
-      { "debug",      no_argument,       NULL, 'd'},
-#endif
+      DEBUG_LONG_OPTION
       { "help",       no_argument,       NULL, 'h'},
       { "verbose",    no_argument,       NULL, 'v'},
       { NULL,         0,                 NULL, 0},
    };
    pv_t **pv_this = NULL;
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
    LVMTAB_CHECK;
 
    while ( ( c = getopt_long ( argc, argv, options,
@@ -109,15 +104,7 @@ int main ( int argc, char **argv) {
             }
             break;
 
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
  
          case 'h':
          case '?':
@@ -127,10 +114,8 @@ int main ( int argc, char **argv) {
                      "%s\n"
                      "\t[-a/--all]\n"
                      "\t[-A/--autobackup y/n]\n"
-#ifdef DEBUG
-                     "\t[-d/--debug]\n"
-#endif
-                     "\t[-h/-?/--help]\n"
+                     DEBUG_HELP
+                     "\t[-h/--help]\n"
                      "\t[-v/--verbose]\n"
                      "\tVolumeGroupName\n"
                      "\t[PhysicalVolumePath...]\n\n",
