@@ -1,10 +1,11 @@
 /*
  * tools/vgrename.c
  *
- * Copyright (C) 1997 - 1998  Heinz Mauelshagen, Germany
+ * Copyright (C) 1998 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * May-June,September 1998
- * January 1999
+ * January,October 1999
+ * February,September 2000
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with GNU CC; see the file COPYING.  If not, write to
+ * along with LVM; see the file COPYING.  If not, write to
  * the Free Software Foundation, 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA. 
  *
@@ -30,6 +31,11 @@
  *    05/09/1998 - corrected some messages
  *    26/01/1999 - made volume group directory prefix a preprocessor option
  *    28/01/1999 - fixed volume group/path too long in command line
+ *    06/10/1999 - implemented support for long options
+ *    15/02/2000 - use lvm_error()
+ *    27/09/2000 - allow renaming of active volume groups using
+ *                 new vg_rename() function
+ *    23/01/2001 - added call to lvm_init (JT)
  *
  */
 
@@ -49,6 +55,7 @@ int main ( int argc, char** argv) {
    int length = 0;
    int p = 0;
    int opt_A = 1;
+   int opt_A_set = 0;
    int opt_v = 0;
    int ret = 0;
    char *lv_name_ptr = NULL;
@@ -59,20 +66,25 @@ int main ( int argc, char** argv) {
    vg_t *vg = NULL;
    struct stat stat_buf;
 
-#ifdef DEBUG
-   char *options = "A:dh?v";
-#else
-   char *options = "A:h?v";
-#endif
+   char *options = "A:h?v" DEBUG_SHORT_OPTION;
+   struct option long_options[] = {
+      { "autobackup", required_argument, NULL, 'A'},
+      DEBUG_LONG_OPTION
+      { "help",       no_argument,       NULL, 'h'},
+      { "verbose",    no_argument,       NULL, 'v'},
+      { NULL,         0,                 NULL, 0},
+   };
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
    LVMTAB_CHECK;
 
-   while ( ( c = getopt ( argc, argv, options)) != EOF) {
+   while ( ( c = getopt_long ( argc, argv, options,
+                               long_options, NULL)) != EOF) {
       switch ( c) {
          case 'A':
+            opt_A_set++;
             if ( opt_A > 1) {
                fprintf ( stderr, "%s -- A option already given\n\n", cmd);
                return LVM_EINVALID_CMD_LINE;
@@ -86,31 +98,21 @@ int main ( int argc, char** argv) {
             }
             break;
 
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
 
          case 'h':
          case '?':
-            printf ( "\n%s\n\n%s -- Volume Group Rename\n\n"
+            printf ( "\n%s  (IOP %d)\n\n%s -- Volume Group Rename\n\n"
                      "Synopsis:\n"
                      "---------\n\n"
                      "%s\n"
-                     "\t[-A y/n]\n"
-#ifdef DEBUG
-                     "\t[-d]\n"
-#endif
-                     "\t[-h/?]\n"
-                     "\t[-v]\n"
+                     "\t[-A/--autobackup y/n]\n"
+                     DEBUG_HELP
+                     "\t[-h/--help]\n"
+                     "\t[-v/--verbose]\n"
                      "\tOldVolumeGroupPath NewVolumeGroupPath /\n"
                      "\tOldVolumeGroupName NewVolumeGroupName\n\n",
-                     lvm_version, cmd, cmd);
+                     lvm_version, LVM_LIB_IOP_VERSION,  cmd, cmd);
             return 0;
             break;
 
@@ -132,6 +134,8 @@ int main ( int argc, char** argv) {
    CMD_MINUS_CHK;
    LVM_CHECK_IOP;
    LVM_LOCK ( 0);
+   CMD_CHECK_OPT_A_SET;
+
 
    if ( argc - optind != 2) {
       fprintf ( stderr, "%s -- invalid command line\n\n", cmd);
@@ -172,11 +176,15 @@ int main ( int argc, char** argv) {
    }
 
    if ( strncmp ( vg_name_old, LVM_DIR_PREFIX, length) != 0) {
-      sprintf ( vg_name_old_buf, LVM_DIR_PREFIX "%s%c", vg_name_old, 0);
+      memset ( vg_name_old_buf, 0 , sizeof ( vg_name_old_buf));
+      snprintf ( vg_name_old_buf, sizeof ( vg_name_old_buf) - 1,
+                                  LVM_DIR_PREFIX "%s", vg_name_old);
       vg_name_old = vg_name_old_buf;
    }
    if ( strncmp ( vg_name_new, LVM_DIR_PREFIX, length) != 0) {
-      sprintf ( vg_name_new_buf, LVM_DIR_PREFIX "%s%c", vg_name_new, 0);
+      memset ( vg_name_new_buf, 0 , sizeof ( vg_name_new_buf));
+      snprintf ( vg_name_new_buf, sizeof ( vg_name_new_buf) - 1,
+                                  LVM_DIR_PREFIX "%s", vg_name_new);
       vg_name_new = vg_name_new_buf;
    }
 
@@ -201,13 +209,6 @@ int main ( int argc, char** argv) {
       return LVM_EVGRENAME_VG_CHECK_EXIST_OLD;
    }
 
-   if ( vg_check_active ( vg_name_old) == TRUE) {
-      fprintf ( stderr, "%s -- ERROR: volume group \"%s\" must be inactive to "
-                        "be renamed\n\n",
-                        cmd, vg_name_old);
-      return LVM_EVGRENAME_VG_CHECK_ACTIVE;
-   }
-
    if ( strcmp ( vg_name_old, vg_name_new) == 0) {
       fprintf ( stderr, "%s -- ERROR: volume group names "
                         "must be different\n\n", cmd);
@@ -227,9 +228,9 @@ int main ( int argc, char** argv) {
                             "\"%s\"\n",
                             cmd, vg_name_old, LVMTAB);
    if ( ( ret = lvm_tab_vg_read_with_pv_and_lv ( vg_name_old, &vg)) != 0) {
-      fprintf ( stderr, "%s -- ERROR %d getting data of volume "
+      fprintf ( stderr, "%s -- ERROR \"%s\" getting data of volume "
                         "group \"%s\"\n\n",
-                        cmd, ret, vg_name_old);
+                        cmd, lvm_error ( ret), vg_name_old);
       return LVM_EVGRENAME_VG_READ;
    }
 
@@ -256,19 +257,28 @@ int main ( int argc, char** argv) {
    /* end change the volume name in all structures */
 
 
+   if ( opt_v > 0) printf ( "%s -- renaming volume group \"%s\"in kernel\n",
+                            cmd, vg_name_old);
+   if ( ( ret = vg_rename ( vg_name_old, vg_name_new)) < 0) {
+      fprintf ( stderr, "%s -- ERROR \"%s\" renaming volume group \"%s\""
+                        " in kernel\n\n", 
+                        cmd, lvm_error ( ret), vg_name_old);
+      return LVM_EVGRENAME_VG_RENAME;
+   }
+
    /* store it on disks */
    if ( opt_v > 0) printf ( "%s -- storing VGDA on disk(s)\n",
                             cmd);
    if ( ( ret = vg_write_with_pv_and_lv ( vg)) != 0) {
-      fprintf ( stderr, "%s -- ERROR %d storing data of volume group \"%s\""
+      fprintf ( stderr, "%s -- ERROR \"%s\" storing data of volume group \"%s\""
                         " on disks\n\n", 
-                cmd, ret, vg_name_new);
+                        cmd, lvm_error ( ret), vg_name_new);
       fprintf ( stderr, "%s -- removing new VGDA of \"%s\" from kernel\n",
                         cmd, vg_name_new);
       if ( ( ret = vg_remove ( vg_name_new)) < 0)
-         fprintf ( stderr, "%s -- ERROR %d removing VGDA of \"%s\" "
+         fprintf ( stderr, "%s -- ERROR \"%s\" removing VGDA of \"%s\" "
                            "from kernel\n\n",
-                           cmd, ret, vg_name_new);
+                           cmd, lvm_error ( ret), vg_name_new);
       return LVM_EVGRENAME_VG_REMOVE;
    }
 
@@ -277,9 +287,9 @@ int main ( int argc, char** argv) {
                             "volume group \"%s\"\n",
                             cmd, LVMTAB, vg_name_old);
    if ( ( ret = lvm_tab_vg_remove ( vg_name_old)) < 0) {
-      fprintf ( stderr, "%s -- ERROR %d removing volume group \"%s\" "
+      fprintf ( stderr, "%s -- ERROR \"%s\" removing volume group \"%s\" "
                         "from \"%s\"\n\n",
-                        cmd, ret, vg_name_old, LVMTAB);
+                        cmd, lvm_error ( ret), vg_name_old, LVMTAB);
       return LVM_EVGRENAME_LVM_TAB_VG_REMOVE;
    }
 
@@ -316,10 +326,10 @@ int main ( int argc, char** argv) {
                            "%s/group\n",
                            cmd, vg_name_new);
       } else {
-         fprintf ( stderr, "%s -- ERROR %d creating volume group directory "
+         fprintf ( stderr, "%s -- ERROR \"%s\" creating volume group directory "
                            LVM_DIR_PREFIX
                            "%s\n",
-                   cmd, ret, vg_name_new);
+                           cmd, lvm_error ( ret), vg_name_new);
       }
       return LVM_EVGRENAME_VG_CREATE_DIR_AND_GROUP_NODES;
    }
@@ -329,9 +339,9 @@ int main ( int argc, char** argv) {
                             "into \"%s\"\n",
                             cmd, vg_name_new, LVMTAB);
    if ( ( ret = lvm_tab_vg_insert ( vg_name_new)) < 0) {
-      fprintf ( stderr, "%s -- ERROR %d inserting volume group \"%s\" "
+      fprintf ( stderr, "%s -- ERROR \"%s\" inserting volume group \"%s\" "
                         "into \"%s\"\n\n",
-                        cmd, ret, vg_name_new, LVMTAB);
+                        cmd, lvm_error ( ret), vg_name_new, LVMTAB);
       return LVM_EVGRENAME_VG_INSERT;
    }
 
@@ -342,12 +352,18 @@ int main ( int argc, char** argv) {
                   cmd, vg_name_new);
          if ( ( ret = vg_cfgbackup ( vg_name_new, VG_BACKUP_DIR,
                                      opt_v, vg)) < 0) {
-            fprintf ( stderr, "%s -- ERROR %d writing VG backup\n\n", cmd, ret);
+            fprintf ( stderr, "%s -- ERROR \"%s\" writing VG backup\n\n",
+                              cmd, lvm_error ( ret));
             return LVM_EVGRENAME_VG_CFGBACKUP;
          }
+      } else {
+         printf ( "%s -- WARNING: you don't have an automatic "
+                  "backup of \"%s\"\n",
+                  cmd, vg_name_new);
       }
    } else {
-      fprintf ( stderr, "%s -- ERROR %d writing lvmtab\n\n", cmd, ret);
+      fprintf ( stderr, "%s -- ERROR \"%s\" writing lvmtab\n\n",
+                        cmd, lvm_error ( ret));
       return LVM_EVGRENAME_VG_CFGBACKUP_LVMTAB;
    }
 
